<!DOCTYPE html>
<html>
    <head>
    </head>
    <body>
        <div>
            <p style='font-style:italic;color:#777'><b>{{ author }}</b> {{ object }} de {{ on }}</p>
            <p>{{ instance.summary }}</p>
        </div>
        <div style='margin-top:10px;'>
            <p style='font-size:small;color:#777'>
                --
                <br>
                Ne réponds pas directement à cet e-mail, à la place rends-toi sur <a href='{{ on }}' target='_blank'>{{ on }}</a>.
                <br>
            </p>
        </div>
    </body>
</html>