# Generated by Django 2.2.18 on 2021-02-18 10:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0010_notificationsetting'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='notification',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'ordering': ['-date']},
        ),
        migrations.AlterModelOptions(
            name='subscription',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
    ]
