# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-06-02 10:35
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0005_auto_20200505_1733'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='djangoldp_notification.Subscription'),
        ),
    ]
